```
# Setup postgres docker container
docker create --name student-details-pgdb -e POSTGRES_PASSWORD=admin -p 5432:5432 postgres:11.5-alpine

# Start the postgres docker container
docker start student-details-pgdb

# Below will enter into the psql shell and create the database
docker exec -it student-details-pgdb psql -U postgres
(psql) create database student_details;

# Add DB_URL as environment variable (under app configuration in IntelliJ)
DB_URL=jdbc:postgresql://localhost:5432/student_details

# add the db info into application.properties
spring.datasource.url=${DB_URL}
spring.datasource.username=postgres
spring.datasource.password=admin
spring.jpa.database-platform=org.hibernate.dialect.PostgreSQLDialect
spring.jpa.hibernate.ddl-auto=none
spring.jpa.hibernate.show-sql=true
spring.jpa.properties.hibernate.jdbc.lob.non_contextual_creation=true

# Under resources for the project, we will need to create two SQL files, create_tables.sql and insert_data.sql: one for creating the table, and another one for inserting seed data

CREATE TABLE student_details
(
  id            SERIAL          PRIMARY KEY,
  email         VARCHAR(100)    UNIQUE NOT NULL,
  firstName     VARCHAR(100)    NOT NULL,
  lastName      VARCHAR(100)    NOT NULL,
  dateOfBirth   DATE            NOT NULL,
  course        VARCHAR(100)    NOT NULL
);

# Once we have the files ready, run the commands below to run the SQL in the docker container
docker cp create_tables.sql student-details-pgdb:/create_tables.sql
docker exec -it student-details-pgdb -d student_details -f create_tables.sql -U postgres
docker cp insert_data.sql student-details-pgdb:/insert_data.sql
docker exec -it student-details-pgdb psql -d student_details -f insert_data.sql -U postgres
```